Learn R Programming

hcidata (version 0.1.0)

CasualSteering: Casual Interaction Steering Study

Description

Data from a study on casual interactions where participants had to move a ball from one side of a level to the other. They could use three different kinds of interaction to control the ball: (1) dragging via (2) direct touch, rate-controlled movement via hovering, and (3) fling gestures above the device. Depending on the levels' index of difficulty, the participants picked different interactions to solve the levels.

Usage

CasualSteering

Arguments

Format

A data frame with 84 observations of the following 6 variables:

PID

Participant ID.

level

Level ID.

difficulty

Index of difficulty of the level.

touch

Percentage share of touch interactions.

hover

Percentage share of hover interactions.

gestures

Number of mid-air gestures performed by the participant.

See Also

Other mobile interaction: HandSize