Data from a study on casual interactions where participants had to move a ball from one side of a level to the other. They could use three different kinds of interaction to control the ball: (1) dragging via (2) direct touch, rate-controlled movement via hovering, and (3) fling gestures above the device. Depending on the levels' index of difficulty, the participants picked different interactions to solve the levels.
CasualSteeringA data frame with 84 observations of the following 6 variables:
Participant ID.
Level ID.
Index of difficulty of the level.
Percentage share of touch interactions.
Percentage share of hover interactions.
Number of mid-air gestures performed by the participant.
Other mobile interaction:
HandSize